Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(434)

Unified Diff: content/public/browser/speech_recognition_manager.h

Issue 636863003: Make SpeechRecognition per RenderFrame instead of per RenderView. Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fixes threading issues Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/speech_recognition_manager.h
diff --git a/content/public/browser/speech_recognition_manager.h b/content/public/browser/speech_recognition_manager.h
index f72e75fd9b83e084a178250728fdf4cbc83afa79..6b1906ad5c9f9bd19c8cb6cf3a0cbe9855a9b944 100644
--- a/content/public/browser/speech_recognition_manager.h
+++ b/content/public/browser/speech_recognition_manager.h
@@ -48,13 +48,9 @@ class SpeechRecognitionManager {
// Aborts recognition for an existing session, without providing any result.
virtual void AbortSession(int session_id) = 0;
- // Aborts all sessions for a given render process,
- // without providing any result.
- virtual void AbortAllSessionsForRenderProcess(int render_process_id) = 0;
-
- // Aborts all sessions for a given RenderView, without providing any result.
- virtual void AbortAllSessionsForRenderView(int render_process_id,
- int render_view_id) = 0;
+ // Aborts all sessions for a given RenderFrame, without providing any result.
+ virtual void AbortAllSessionsForRenderFrame(int render_process_id,
+ int render_frame_id) = 0;
// Stops audio capture for an existing session. The audio captured before the
// call will be processed, possibly ending up with a result.
@@ -70,9 +66,9 @@ class SpeechRecognitionManager {
int session_id) const = 0;
// Looks-up an existing session from the context tuple
- // {render_view_id, render_view_id, request_id}.
+ // {render_process_id, render_frame_id, request_id}.
virtual int GetSession(int render_process_id,
- int render_view_id,
+ int render_frame_id,
int request_id) const = 0;
// Returns true if the OS reports existence of audio recording devices.

Powered by Google App Engine
This is Rietveld 408576698